@@ -11,10 +11,6 @@ test_that("getDetectorNames returns correct names", {
   expect_equal(getDetectorNames(mdl), names(train.data$detectors))
 })
 
-test_that("summary returns correct summary matrix", {
-  expect_known_value(summary(mdl), "test-summary")
-})
-
 test_that("numCalls returns number of calls in each detector", {
   expect_known_value(numCalls(mdl), "test-numCalls")
 })
